@@ -214,78 +214,6 @@ def program_to_text(program):
   return s.getvalue()
 
 
-def program_to_dot(program, ignored, only_cfg=False):
-  """Convert a cfg.Program into a dot file.
-
-  Args:
-    program: The program to convert.
-    ignored: A set of names that should be ignored. This affects most kinds of
-    nodes.
-    only_cfg: If set, only output the control flow graph.
-  Returns:
-    A str of the dot code.
-  """
-  def objname(n):
-    return n.__class__.__name__ + str(id(n))
-
-  def objrepr(n):
-    return repr(n.data)[:10].replace("\"", "\\\"").replace("{", r"\{")
-
-  print("cfg nodes=%d, vals=%d, variables=%d" % (
-      len(program.cfg_nodes),
-      sum(len(v.bindings) for v in program.variables),
-      len(program.variables)))
-
-  sb = io.StringIO()
-  sb.write("digraph {\n")
-  for node in program.cfg_nodes:
-    if node in ignored:
-      continue
-    sb.write("%s[shape=polygon,sides=4,label=\"<%d>%s\"];\n"
-             % (objname(node), node.id, node.name))
-    for other in node.outgoing:
-      sb.write("%s -> %s [penwidth=2.0];\n" % (objname(node), objname(other)))
-
-  if only_cfg:
-    sb.write("}\n")
-    return sb.getvalue()
-
-  for variable in program.variables:
-    if variable.id in ignored:
-      continue
-    constant = True
-    for value in variable.bindings:
-      if any(origin.where != program.entrypoint for origin in value.origins):
-        constant = False
-        break
-    if constant:
-      # Ignore "boring" values (a.k.a. constants)
-      continue
-    sb.write('%s[label="%d",shape=polygon,sides=4,distortion=.1];\n'
-             % (objname(variable), variable.id))
-    for val in variable.bindings:
-      sb.write("%s -> %s [arrowhead=none];\n" %
-               (objname(variable), objname(val)))
-      sb.write("%s[label=\"%s@0x%x\",fillcolor=%s];\n" %
-               (objname(val), objrepr(val), id(val.data),
-                "white" if val.origins else "red"))
-      for loc, srcsets in val.origins:
-        if loc == program.entrypoint:
-          continue
-        for srcs in srcsets:
-          sb.write("%s[label=\"\"];\n" % (objname(srcs)))
-          sb.write("%s -> %s [color=pink,arrowhead=none,weight=40];\n"
-                   % (objname(val), objname(srcs)))
-          if loc not in ignored:
-            sb.write("%s -> %s [style=dotted,arrowhead=none,weight=5]\n"
-                     % (objname(loc), objname(srcs)))
-          for src in srcs:
-            sb.write("%s -> %s [color=lightblue,weight=2];\n"
-                     % (objname(src), objname(srcs)))
-  sb.write("}\n")
-  return sb.getvalue()
-
-
 def root_cause(binding, node, seen=()):
   """Tries to determine why a binding isn't possible at a node.
 
